@@ -5,30 +5,31 @@ import ten99policy
 
 # -----------------------------------------------------------------------------------*/
 # Creating a quote
-#-----------------------------------------------------------------------------------*/
+# -----------------------------------------------------------------------------------*/
 
 resource = ten99policy.Quotes.create(
-    job_id="jb_jsb9KEcTpc",
-    contractor_id="cn_yJBbMeq9QA",
-    coverage_type="general"
+    job="jb_jsb9KEcTpc",
+    contractor="cn_yJBbMeq9QA",
+    coverage_type=["general", "workers-comp"],
 )
 
 # -----------------------------------------------------------------------------------*/
 # Updating a quote (replace xxx with an existing quote id)
-#-----------------------------------------------------------------------------------*/
+# -----------------------------------------------------------------------------------*/
 
-resource = ten99policy.Quotes.modify('qt_C9Z2DmfHSF',
-    name='Mechanic',
+resource = ten99policy.Quotes.modify(
+    "qt_C9Z2DmfHSF",
+    name="Mechanic",
 )
 
 # -----------------------------------------------------------------------------------*/
 # Fetching the list of quotes
-#-----------------------------------------------------------------------------------*/
+# -----------------------------------------------------------------------------------*/
 
 resource = ten99policy.Quotes.list()
 
 # -----------------------------------------------------------------------------------*/
 # Retrieving a quote (replace xxx with an existing quote id)
-#-----------------------------------------------------------------------------------*/
+# -----------------------------------------------------------------------------------*/
 
-resource = ten99policy.Quotes.retrieve('qt_C9Z2DmfHSF')
\ No newline at end of file
+resource = ten99policy.Quotes.retrieve("qt_C9Z2DmfHSF")
